@@ -7,6 +7,7 @@ import signal
 import readline
 
 from promptly.styles import Style
+from promptly.styles import AnsiStyle
 from promptly.utils import prepare_stylesheet
 from promptly.renderers import console
 from promptly.compat import input as get_input
@@ -123,12 +124,18 @@ class ConsoleRunner(object):
         styles_action = Style.styles_for_key('action', stylesheet)
         styles_input = Style.styles_for_key('input', stylesheet)
 
-        return '\n%(prompt)s\n%(action)s%(input)s' % {
-            'prompt': prompt,
+        # there appears to be an issue when feeding the whole
+        # prompt to input/raw_input (py3 and py2 respectively)
+        # So we send the text part of the prompt to stdout
+        # and only actualy have the single line with the
+        # prompt/default go to input/raw_input
+        sys.stdout.write('\n%s\n' % prompt)
+
+        return '%(action)s%(input)s' % {
             'action': styles_action('> '),
-            'input': styles_input.color + \
-                     styles_input.background_color + \
-                     styles_input.font_weight
+            'input': styles_input.color +
+            styles_input.background_color +
+            styles_input.font_weight
         }
 
     def render(self, value, default=None):
@@ -151,4 +158,5 @@ class ConsoleRunner(object):
         else:
             result = get_input(self.prompt_format(value))
 
+        sys.stdout.write(AnsiStyle.RESET_ALL)
         return result
